build_psi

Function build_psi 

pub fn build_psi(
    snapshot: &SpecSnapshot,
    target_value: Value,
) -> Result<LambdaPsi, EpistemicDegradationError>
Construct ψ from a spec snapshot and a resolved target value (here represented as a JSON value to keep the Rust runner uniform with the string-typed ExecContext).