pub fn parse_refinement_annotation(body: &str) -> Option<RefinementAnnotation>Expand description
Parse a refinement annotation body of the form hmac or
hmac, key=env.HMAC_KEY. Returns None when the proof slug is not
in TRUST_CATALOG so the checker can emit a targeted error.