pub struct LeaseKernel { /* private fields */ }Expand description
In-process registry of active leases.
Implementations
Sourceimpl LeaseKernel
impl LeaseKernel
pub fn new() -> Self
pub fn with_clock(clock: Clock) -> Self
Sourcepub fn acquire(
&mut self,
ir_lease: &IRLease,
ir_resource: &IRResource,
) -> Result<LeaseToken, HandlerError>
pub fn acquire( &mut self, ir_lease: &IRLease, ir_resource: &IRResource, ) -> Result<LeaseToken, HandlerError>
Mint a fresh token for a lease against a resource. Rejects persistent resources (defence in depth — the type-checker already did this).
Sourcepub fn use_token(
&mut self,
token: &LeaseToken,
) -> Result<UseOutcome, HandlerError>
pub fn use_token( &mut self, token: &LeaseToken, ) -> Result<UseOutcome, HandlerError>
Verify the token is still valid and apply on_expire policy on decay.
Sourcepub fn release(&mut self, token: &LeaseToken)
pub fn release(&mut self, token: &LeaseToken)
Explicitly revoke a token. Idempotent.
Sourcepub fn sweep(&mut self) -> Vec<LeaseToken>
pub fn sweep(&mut self) -> Vec<LeaseToken>
Purge tokens whose τ has elapsed. Returns the removed tokens.
Sourcepub fn active(&self) -> Vec<LeaseToken>
pub fn active(&self) -> Vec<LeaseToken>
Snapshot of currently-valid tokens.
pub fn contains(&self, token_id: &str) -> bool