pub fn dispatch(tool_name: &str, argument: &str) -> Option<ToolResult>Expand description
Dispatch a tool call by name. Returns None if the tool is not a native executor.
pub fn dispatch(tool_name: &str, argument: &str) -> Option<ToolResult>Dispatch a tool call by name. Returns None if the tool is not a native executor.