pub fn diff_versions(
registry: &VersionRegistry,
flow_name: &str,
from_version: u32,
to_version: u32,
) -> Result<VersionDiff, String>Expand description
Diff two versions of a flow from the registry.
pub fn diff_versions(
registry: &VersionRegistry,
flow_name: &str,
from_version: u32,
to_version: u32,
) -> Result<VersionDiff, String>Diff two versions of a flow from the registry.