parse_refinement_annotation

Function parse_refinement_annotation 

pub fn parse_refinement_annotation(body: &str) -> Option<RefinementAnnotation>
Parse a refinement annotation body of the form hmac or hmac, key=env.HMAC_KEY. Returns None when the proof slug is not in TRUST_CATALOG so the checker can emit a targeted error.